@@ -244,6 +244,40 @@ def nse_quote_ltp(symbol,expiryDate="latest",optionType="-",strikePrice=0):
   # print(nse_quote_ltp("BANKNIFTY","13-Aug-2020","PE",21000))
   # print(nse_quote_ltp("RELIANCE","latest","PE",2300))
 
+def nse_quote_meta(symbol,expiryDate="latest",optionType="-",strikePrice=0):
+  payload = nse_quote(symbol)
+  #https://stackoverflow.com/questions/7961363/removing-duplicates-in-lists
+  #https://stackoverflow.com/questions/19199984/sort-a-list-in-python
+  if(expiryDate=="latest") or (expiryDate=="next"):
+    if(optionType!="Fut"):
+      dates=list(set((payload["expiryDates"])))
+      dates.sort(key = lambda date: datetime.datetime.strptime(date, '%d-%b-%Y'))
+      expiryDate=dates[0]
+      if(expiryDate=="next"):expiryDate=dates[1]
+
+  meta = "Options"
+  if(optionType=="Fut"): meta = "Futures"
+  if(optionType=="PE"):optionType="Put"
+  if(optionType=="CE"):optionType="Call"
+
+  if(optionType!="-"):
+      for i in payload['stocks']:
+        if meta in i['metadata']['instrumentType']:
+          #print(i['metadata'])
+          if(expiryDate=="latest"):
+            metadata = i['metadata']
+            break
+
+          if (i['metadata']["expiryDate"]==expiryDate):
+            if (i['metadata']["optionType"]==optionType):
+              if (i['metadata']["strikePrice"]==strikePrice):
+                metadata = i['metadata']
+
+  if(optionType=="-"):
+      metadata = payload['info']
+
+  return metadata
+
 def nse_optionchain_ltp(payload,strikePrice,optionType,inp=0,intent=""):
     expiryDate=payload['records']['expiryDates'][inp]
     for x in range(len(payload['records']['data'])):
